@@ -4,7 +4,7 @@ from usttc.audio.audio_file import AudioFile, AudioFormat
 from usttc.result.recognize_result import RecognizeResult
 from usttc.result.word import Word
 from usttc.exceptions.exceptions import ConfigurationException, AudioException
-from usttc.utils import generate_random_str
+from usttc.utils.utils import generate_random_str
 from usttc.stream.stream_results import StreamResult, StreamResults
 from usttc.stream.stream import Stream
 from google.cloud import speech
@@ -17,20 +17,27 @@ AUDIO_DURATION_LIMIT = 480 * 60
 class GoogleClient(AsrClient):
     provider = AsrProvider.GOOGLE
 
-    def __init__(self, client, storage_client, google_storage_bucket):
+    def __init__(self, client, storage_client, google_storage_bucket, google_model):
         self.client = client
         self.storage_client = storage_client
         self.google_storage_bucket = google_storage_bucket
+        self.google_model = google_model
 
     def recognize(self, audio: AudioFile, config: Config = Config()):
         if audio.duration >= AUDIO_DURATION_LIMIT:
             raise AudioException("Google does not support audio longer than 480 minutes")
 
         convert_audio = False
-        if (audio.codec not in {AudioFormat.LINEAR16, AudioFormat.FLAC, AudioFormat.MULAW, AudioFormat.AMR}) or \
-            ((audio.codec not in {AudioFormat.LINEAR16, AudioFormat.FLAC})
+        if audio.channels > 1 and not config.separate_speaker_per_channel:
+            audio = audio.convert(to_mono=True)
+            convert_audio = True
+        elif (
+                audio.codec not in {AudioFormat.LINEAR16, AudioFormat.FLAC, AudioFormat.MULAW, AudioFormat.AMR}
+            ) or (
+                (audio.codec not in {AudioFormat.LINEAR16, AudioFormat.FLAC})
                 and (audio.channels > 1)
-                and config.separate_speaker_per_channel):
+                and config.separate_speaker_per_channel
+            ):
             audio = audio.convert()
             convert_audio = True
 
@@ -90,7 +97,7 @@ class GoogleClient(AsrClient):
             encoding=audio.codec.name,
             sample_rate_hertz=audio.sample_rate,
             language_code=config.language,
-            model="video",
+            model=self.google_model,
             use_enhanced=True,
             enable_word_time_offsets=True,
             enable_automatic_punctuation=True
@@ -108,6 +115,12 @@ class GoogleClient(AsrClient):
             recognition_config.enable_separate_recognition_per_channel = True
             recognition_config.audio_channel_count = audio.channels
 
+        if config.hints:
+            speech_context = speech.SpeechContext(
+                phrases=config.hints
+            )
+            recognition_config.speech_contexts = [speech_context]
+
         operation = self.client.long_running_recognize(config=recognition_config, audio=recog_audio)
         response = operation.result()
         words = []
@@ -120,6 +133,8 @@ class GoogleClient(AsrClient):
                     speaker = current_channel_tag
                 else:
                     speaker = w.speaker_tag
+                if config.diarization and not speaker:
+                    continue
                 words.append(Word(text=w.word, start=start, end=end, speaker=speaker))
 
         return RecognizeResult(transcript=None, words=words)
@@ -135,9 +150,12 @@ class GoogleClient(AsrClient):
         google_storage_bucket = kwargs.get("google_storage_bucket")
         if not google_storage_bucket:
             raise ConfigurationException("Google ASR: Specify google_storage_bucket arg")
+        google_model = kwargs.get("google_model")
+        if google_model is None:
+            google_model = "video"
         client = speech.SpeechClient.from_service_account_file(filename)
         storage_client = storage.Client.from_service_account_json(filename)
-        return GoogleClient(client, storage_client, google_storage_bucket)
+        return GoogleClient(client, storage_client, google_storage_bucket, google_model)
 
     @staticmethod
     def from_key(key: str, *args, **kwargs):
